package com.nemock.ShowDurability1.core.handler;

import java.text.MessageFormat;

import com.nemock.ShowDurability1.lib.States;

import net.minecraft.client.Minecraft;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.EnumChatFormatting;
import net.minecraftforge.event.EventPriority;
import net.minecraftforge.event.ForgeSubscribe;
import net.minecraftforge.event.entity.player.ItemTooltipEvent;

public class ShowDurabilityEventHandler {

	public Minecraft mc;

	public ShowDurabilityEventHandler(Minecraft minecraft) {
		this.mc = minecraft;
	}

	@ForgeSubscribe(priority = EventPriority.HIGH)
	public void handleItemTooltip(ItemTooltipEvent event) {
		if (event.showAdvancedItemTooltips) {
			if (event.itemStack.getItem().isDamaged(event.itemStack)) {
				event.toolTip.remove(event.toolTip.size() - 1);
			}
		}

		if (event.itemStack.getItem().isDamageable()) {
			event.toolTip.add(1, generateDurText(event.itemStack));
		}

	}

	private String generateDurText(ItemStack stack) {
		String result = "";
		result += getCaption();
		result += getColor(stack);
		result += getFormatedDurability(stack);
		if (States.color) {
			result += EnumChatFormatting.RESET;
		}
		return result;
	}

	private String getCaption() {
		String result = "";
		if (!(States.durCaption == null) || !(States.durCaption == "")) {
			result = States.durCaption + " ";
		}
		return result;
	}

	private String getColor(ItemStack stack) {
		String color = "";
		if (States.color) {
			int maxDmg = stack.getMaxDamage() + 1;
			int durability = maxDmg - stack.getItemDamageForDisplay();

			if (durability > (maxDmg / 4 * 3)) {
				color += EnumChatFormatting.GREEN;
			} else if (durability > (maxDmg / 4 * 2)) {
				color += EnumChatFormatting.YELLOW;
			} else if (durability > maxDmg / 4) {
				color += EnumChatFormatting.GOLD;
			} else {
				color += EnumChatFormatting.RED;
			}
		}
		return color;
	}

	private String getFormatedDurability(ItemStack stack) {
		String result = "";
		int maxDmg = 0;
		int tmpDmg = 0;
		int durability = 0;
		if (isTCTool(stack)) {
			NBTTagCompound tag = stack.getTagCompound()
					.getCompoundTag("InfiTool");
			if (tag.hasKey("BaseDurability")) {
				maxDmg = tag.getInteger("BaseDurability")
						+ tag.getInteger("BonusDurability");
				tmpDmg = tag.getInteger("Damage");
			}
		} else {
			maxDmg = stack.getMaxDamage() + 1;
			tmpDmg = stack.getItemDamageForDisplay();
		}
		durability = maxDmg - tmpDmg;
		Object stats[] = { Integer.toString(durability),
				Integer.toString(maxDmg) };
		MessageFormat durString = new MessageFormat(States.durFormat);
		result = durString.format(stats);
		return result;
	}
	
	private boolean isTCTool(ItemStack stack) {
		boolean isTCItem = stack.hasTagCompound()
				&& stack.stackTagCompound.hasKey("InfiTool");
		return (isTCItem && !stack.isStackable());
	}
}
